@@ -10,13 +10,15 @@ https://mypy.readthedocs.io/en/stable/protocols.html
 
 from typing import TYPE_CHECKING, Any, Callable, Generator, Optional
 
-from selenium.webdriver.common.action_chains import ActionChains
-from typing_extensions import Protocol
+from typing_extensions import Protocol, runtime_checkable
 
 if TYPE_CHECKING:
     from .actor import Actor
 
+# pylint: disable=unused-argument
 
+
+@runtime_checkable
 class Answerable(Protocol):
     """Questions are Answerable"""
 
@@ -26,28 +28,14 @@ class Answerable(Protocol):
         answer to their best knowledge.
 
         Args:
-            the_actor: the |Actor| who will answer the |Question|.
+            the_actor: the Actor who will answer the Question.
 
         Returns:
             The answer, based on the sleuthing the Actor has done.
         """
-        ...
-
-
-class Chainable(Protocol):
-    """Actions that can be added to a chain are Chainable"""
-
-    def add_to_chain(self, the_actor: "Actor", the_chain: ActionChains) -> None:
-        """
-        Add this chainable Action to an in-progress chain.
-
-        Args:
-            the_actor: the |Actor| who will be performing the |Action| chain.
-            the_chain: the |ActionChains| instance that is being built.
-        """
-        ...
 
 
+@runtime_checkable
 class Forgettable(Protocol):
     """Abilities are Forgettable"""
 
@@ -56,9 +44,9 @@ class Forgettable(Protocol):
         Forget this Ability by doing any necessary cleanup (quitting browsers,
         closing connections, etc.)
         """
-        ...
 
 
+@runtime_checkable
 class Performable(Protocol):
     """Actions that can be performed are Performable"""
 
@@ -67,19 +55,34 @@ class Performable(Protocol):
         Direct the Actor to perform this Action.
 
         Args:
-            the_actor: the |Actor| who will perform this |Action|.
+            the_actor: the Actor who will perform this Action.
         """
-        ...
 
 
+@runtime_checkable
+class ErrorKeeper(Protocol):
+    """Classes that save exceptions for later are ErrorKeeper(s)"""
+
+    caught_exception: Optional[Exception]
+
+
+@runtime_checkable
+class Describable(Protocol):
+    """Classes that describe themselves are Describable"""
+
+    def describe(self) -> str:
+        """Describe the Describable in the present tense."""
+
+
+@runtime_checkable
 class Adapter(Protocol):
-    """Required functions for an Adapter to the Narrator's microphone.
+    """Required functions for an adapter to the Narrator's microphone.
 
-    Adapters allow the Narrator's microphone to broadcast to multiple logging
-    sources, such as stdout or Allure.
+    Adapters allow the :ref:`Narrator <narrator api>`'s microphone to
+    broadcast to multiple reporting tools, such as stdout or Allure.
 
     Each of the methods described below correspond to the ``screenpy.pacing``
-    decorators of the same name. The narrator expects each of these methods to
+    decorators of the same name. The Narrator expects each of these methods to
     yield the function back. This allows each adapter to modify the function
     in whatever ways it needs to while allowing the adapters before and after
     to do the same.
@@ -93,18 +96,23 @@ class Adapter(Protocol):
         self, func: Callable, line: str, gravitas: Optional[str] = None
     ) -> Generator:
         """Handle narrating an Act, which designates a group of tests."""
-        ...
 
     def scene(
         self, func: Callable, line: str, gravitas: Optional[str] = None
     ) -> Generator:
         """Handle narrating a Scene, which designates a subgroup of tests."""
-        ...
 
     def beat(self, func: Callable, line: str) -> Generator:
         """Handle narrating a Beat, which is a step in a test."""
-        ...
 
     def aside(self, func: Callable, line: str) -> Generator:
         """Handle narrating an Aside, which can happen any time."""
-        ...
+
+    def error(self, exc: Exception) -> None:
+        """React to an exception being thrown, probably during a beat."""
+
+    def attach(self, filepath: str, **kwargs: Any) -> None:
+        """Handle attaching a file.
+
+        Pass keyword arguments for specific adapters' needs.
+        """
