@@ -2,10 +2,15 @@
 Matches a list that contains the desired item.
 """
 
+from typing import TypeVar
+
 from hamcrest import has_item
+from hamcrest.library.collection.issequence_containing import IsSequenceContaining
 
 from .base_resolution import BaseResolution
 
+T = TypeVar("T")
+
 
 class ContainsTheItem(BaseResolution):
     """Match an iterable containing a specific item.
@@ -17,5 +22,9 @@ class ContainsTheItem(BaseResolution):
         )
     """
 
-    line = 'list containing the item "{expectation}"'
+    matcher: IsSequenceContaining
+    line = 'a list containing the item "{expectation}"'
     matcher_function = has_item
+
+    def __init__(self, match: T) -> None:
+        super().__init__(match)
