@@ -2,7 +2,10 @@
 Matches a dictionary that contains the desired key.
 """
 
+from typing import Hashable
+
 from hamcrest import has_key
+from hamcrest.library.collection.isdict_containingkey import IsDictContainingKey
 
 from .base_resolution import BaseResolution
 
@@ -15,5 +18,9 @@ class ContainsTheKey(BaseResolution):
         the_actor.should(See.the(LastResponseBody(), ContainsTheKey("skeleton")))
     """
 
-    line = 'dict containing the key "{expectation}"'
+    matcher: IsDictContainingKey
+    line = 'a dict containing the key "{expectation}"'
     matcher_function = has_key
+
+    def __init__(self, key_match: Hashable) -> None:
+        super().__init__(key_match)
