@@ -3,6 +3,7 @@ Matches a substring.
 """
 
 from hamcrest import contains_string
+from hamcrest.library.text.stringcontains import StringContains
 
 from .base_resolution import BaseResolution
 
@@ -17,5 +18,9 @@ class ContainsTheText(BaseResolution):
         )
     """
 
+    matcher: StringContains
     line = 'text containing "{expectation}"'
     matcher_function = contains_string
+
+    def __init__(self, match: str) -> None:
+        super().__init__(match)
