@@ -3,6 +3,7 @@ Matches a value that falls within the range specified by the given delta.
 """
 
 from hamcrest import close_to
+from hamcrest.library.number.iscloseto import IsCloseTo as _IsCloseTo
 
 from .base_resolution import BaseResolution
 
@@ -17,9 +18,13 @@ class IsCloseTo(BaseResolution):
         )
     """
 
+    matcher: _IsCloseTo
     matcher_function = close_to
 
     def get_line(self) -> str:
         """Get the line that describes this Resolution."""
         args, kwargs = self.expected
         return f"a value at most {kwargs['delta']} away from {args[0]}."
+
+    def __init__(self, num: int, delta: int = 1) -> None:
+        super().__init__(num, delta=delta)
