@@ -3,6 +3,7 @@ Matches an empty collection.
 """
 
 from hamcrest import empty
+from hamcrest.library.collection.is_empty import IsEmpty as _IsEmpty
 
 from .base_resolution import BaseResolution
 
@@ -15,5 +16,9 @@ class IsEmpty(BaseResolution):
         the_actor.should(See.the(List.of_all(VIDEO_FRAMES), IsEmpty()))
     """
 
+    matcher: _IsEmpty
     line = "an empty collection"
     matcher_function = empty
+
+    def __init__(self) -> None:
+        super().__init__()
