@@ -2,10 +2,15 @@
 Matches using equality.
 """
 
+from typing import TypeVar
+
 from hamcrest import equal_to
+from hamcrest.core.core.isequal import IsEqual
 
 from .base_resolution import BaseResolution
 
+T = TypeVar("T")
+
 
 class IsEqualTo(BaseResolution):
     """Match on an equal object.
@@ -17,5 +22,9 @@ class IsEqualTo(BaseResolution):
         )
     """
 
+    matcher: IsEqual
     line = "equal to {expectation}"
     matcher_function = equal_to
+
+    def __init__(self, obj: T) -> None:
+        super().__init__(obj)
